]> de.git.xonotic.org Git - xonotic/darkplaces.git/blobdiff - image.h
Add GL_ExtensionSupported in vid_null.c because vid_shared.c relies on
[xonotic/darkplaces.git] / image.h
diff --git a/image.h b/image.h
index a25f2201193578df8475f1ed8ad10f2c11f0dc11..21dc012327b2c6b303b41156171dbfcf8c28f50e 100644 (file)
--- a/image.h
+++ b/image.h
@@ -2,9 +2,9 @@
 #ifndef IMAGE_H
 #define IMAGE_H
 
-
 extern int image_width, image_height;
 
+unsigned char *Image_GenerateNoTexture(void);
 
 // swizzle components (even converting number of components) and flip images
 // (warning: input must be different than output due to non-linear read/write)
@@ -15,70 +15,58 @@ void Image_CopyMux(unsigned char *outpixels, const unsigned char *inpixels, int
 // applies gamma correction to RGB pixels, in can be the same as out
 void Image_GammaRemapRGB(const unsigned char *in, unsigned char *out, int pixels, const unsigned char *gammar, const unsigned char *gammag, const unsigned char *gammab);
 
-// converts 8bit image data to RGBA, in can not be the same as out
-void Image_Copy8bitRGBA(const unsigned char *in, unsigned char *out, int pixels, const unsigned int *pal);
+// converts 8bit image data to BGRA, in can not be the same as out
+void Image_Copy8bitBGRA(const unsigned char *in, unsigned char *out, int pixels, const unsigned int *pal);
 
-// makes a RGBA mask from RGBA input, in can be the same as out
-int image_makemask (const unsigned char *in, unsigned char *out, int size);
+void Image_StripImageExtension (const char *in, char *out, size_t size_out);
 
-unsigned char *LoadTGA (const unsigned char *f, int filesize, int matchwidth, int matchheight);
+// called by conchars.tga loader in gl_draw.c, otherwise private
+unsigned char *LoadTGA_BGRA (const unsigned char *f, int filesize, int *miplevel);
 
 // loads a texture, as pixel data
-unsigned char *loadimagepixels (const char *filename, qboolean complain, int matchwidth, int matchheight);
-
-// loads a texture, as a texture
-rtexture_t *loadtextureimage (rtexturepool_t *pool, const char *filename, int matchwidth, int matchheight, qboolean complain, int flags);
+unsigned char *loadimagepixelsbgra (const char *filename, qboolean complain, qboolean allowFixtrans, qboolean convertsRGB, int *miplevel);
 
-// loads a texture's alpha mask, as pixel data
-unsigned char *loadimagepixelsmask (const char *filename, qboolean complain, int matchwidth, int matchheight);
+// searches for lmp and wad pics of the provided name and returns true and their dimensions if found
+qboolean Image_GetStockPicSize(const char *filename, int *returnwidth, int *returnheight);
 
-// loads a texture's alpha mask, as a texture
-rtexture_t *loadtextureimagemask (rtexturepool_t *pool, const char *filename, int matchwidth, int matchheight, qboolean complain, int flags);
+// loads an 8bit pcx image into a 296x194x8bit buffer, with cropping as needed
+qboolean LoadPCX_QWSkin(const unsigned char *f, int filesize, unsigned char *pixels, int outwidth, int outheight);
 
-// loads a texture and it's alpha mask at once (NULL if it has no translucent pixels)
-extern rtexture_t *image_masktex;
-extern rtexture_t *image_nmaptex;
-rtexture_t *loadtextureimagewithmask (rtexturepool_t *pool, const char *filename, int matchwidth, int matchheight, qboolean complain, int flags);
-rtexture_t *loadtextureimagewithmaskandnmap (rtexturepool_t *pool, const char *filename, int matchwidth, int matchheight, qboolean complain, int flags, float bumpscale);
-rtexture_t *loadtextureimagebumpasnmap (rtexturepool_t *pool, const char *filename, int matchwidth, int matchheight, qboolean complain, int flags, float bumpscale);
+// loads the palette from an 8bit pcx image into your provided array
+qboolean LoadPCX_PaletteOnly(const unsigned char *f, int filesize, unsigned char *palette768b);
 
-// writes a RGB TGA that is already upside down (which TGA wants)
-qboolean Image_WriteTGARGB_preflipped (const char *filename, int width, int height, const unsigned char *data, unsigned char *buffer);
+// get the metadata from a Quake2 wal file
+qboolean LoadWAL_GetMetadata(const unsigned char *f, int filesize, int *retwidth, int *retheight, int *retflags, int *retvalue, int *retcontents, char *retanimname32c);
 
-// writes a RGB TGA
-void Image_WriteTGARGB (const char *filename, int width, int height, const unsigned char *data);
+// loads a texture, as a texture
+rtexture_t *loadtextureimage (rtexturepool_t *pool, const char *filename, qboolean complain, int flags, qboolean allowFixtrans, qboolean sRGB);
 
-// writes a RGBA TGA
-void Image_WriteTGARGBA (const char *filename, int width, int height, const unsigned char *data);
+// writes an upside down BGR image into a TGA
+qboolean Image_WriteTGABGR_preflipped (const char *filename, int width, int height, const unsigned char *data);
 
-// returns true if the image has some translucent pixels
-qboolean Image_CheckAlpha(const unsigned char *data, int size, qboolean rgba);
+// writes a BGRA image into a TGA file
+qboolean Image_WriteTGABGRA (const char *filename, int width, int height, const unsigned char *data);
 
 // resizes the image (in can not be the same as out)
-void Image_Resample (const void *indata, int inwidth, int inheight, int indepth, void *outdata, int outwidth, int outheight, int outdepth, int bytesperpixel, int quality);
+void Image_Resample32(const void *indata, int inwidth, int inheight, int indepth, void *outdata, int outwidth, int outheight, int outdepth, int quality);
 
 // scales the image down by a power of 2 (in can be the same as out)
-void Image_MipReduce(const unsigned char *in, unsigned char *out, int *width, int *height, int *depth, int destwidth, int destheight, int destdepth, int bytesperpixel);
-
-// only used by menuplyr coloring
-unsigned char *LoadLMP (const unsigned char *f, int filesize, int matchwidth, int matchheight, qboolean loadAs8Bit);
-
-void Image_HeightmapToNormalmap(const unsigned char *inpixels, unsigned char *outpixels, int width, int height, int clamp, float bumpscale);
-
-typedef struct imageskin_s
-{
-       unsigned char *basepixels;int basepixels_width;int basepixels_height;
-       unsigned char *nmappixels;int nmappixels_width;int nmappixels_height;
-       unsigned char *glowpixels;int glowpixels_width;int glowpixels_height;
-       unsigned char *glosspixels;int glosspixels_width;int glosspixels_height;
-       unsigned char *pantspixels;int pantspixels_width;int pantspixels_height;
-       unsigned char *shirtpixels;int shirtpixels_width;int shirtpixels_height;
-       unsigned char *maskpixels;int maskpixels_width;int maskpixels_height;
-}
-imageskin_t;
-
-int image_loadskin(imageskin_t *s, char *name);
-void image_freeskin(imageskin_t *s);
+void Image_MipReduce32(const unsigned char *in, unsigned char *out, int *width, int *height, int *depth, int destwidth, int destheight, int destdepth);
+
+void Image_HeightmapToNormalmap_BGRA(const unsigned char *inpixels, unsigned char *outpixels, int width, int height, int clamp, float bumpscale);
+
+// console command to fix the colors of transparent pixels (to prevent weird borders)
+void Image_FixTransparentPixels_f(void);
+extern cvar_t r_fixtrans_auto;
+
+#define Image_LinearFloatFromsRGBFloat(c) (((c) <= 0.04045f) ? (c) * (1.0f / 12.92f) : (float)pow(((c) + 0.055f)*(1.0f/1.055f), 2.4f))
+#define Image_sRGBFloatFromLinearFloat(c) (((c) < 0.0031308f) ? (c) * 12.92f : 1.055f * (float)pow((c), 1.0f/2.4f) - 0.055f)
+#define Image_LinearFloatFromsRGB(c) Image_LinearFloatFromsRGBFloat((c) * (1.0f / 255.0f))
+#define Image_sRGBFloatFromLinear(c) Image_sRGBFloatFromLinearFloat((c) * (1.0f / 255.0f))
+#define Image_sRGBFloatFromLinear_Lightmap(c) Image_sRGBFloatFromLinearFloat((c) * (2.0f / 255.0f)) * 0.5f
+
+void Image_MakeLinearColorsFromsRGB(unsigned char *pout, const unsigned char *pin, int numpixels);
+void Image_MakesRGBColorsFromLinear_Lightmap(unsigned char *pout, const unsigned char *pin, int numpixels);
 
 #endif